opencv-proto documentation
==========================
https://github.com/idlesign/opencv-proto



Description
-----------

*Allows fast prototyping in Python for OpenCV*

Offers primitives and simplified interfaces to streamline prototypes construction in Python.

Facilitates:

* Windows construction and management
* Trackbar construction
* Configuration save/load (including trackbar values)
* Key binding (e.g. for trackbar control, configuration save/load)
* Video capturing and modification
* Work with images
* Frames transformation


Requirements
------------

1. Python 3.6+
2. ``opencv-python`` (or variants)


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart

